# Roboflow Transform

## Commands

### Requirements
Python 3.10 (`brew install python@3.10`)

GDAL (`brew install gdal`, necessary for `rasterio`)

### Install
**Note that some dependencies may rely on subdependencies that must be installed first!
If errors arise, update the Makefile to install those subdependencies or list them here.**

```sh
make install
```

### Run Tests
```sh
make test
```

### Format Code
```sh
make format
```

## Explanations

### Testing

There are 3 types of tests in the current test suite:
1. No crash tests
2. Regression tests
3. Unit tests

(1) runs a series of transformations and asserts that none crash.
It does not check whether outputs are correct, only that no exceptions are raised.

(2) checks that outputs are as expected.
The way this works is by checking each transformation output against a predetermined ground truth output.
If the outputs do not match, the tests fail.
This ground truth output must be generated by running `make seed_test`.

`make seed_test` generates a `regression_data` directory in the `tests` directory. `regression_data` contains subdirectories each of name `test_output_<i>`. Each subdirectory contains two files: `image.png` and `annotations.json`. These are the image/annotation pairs for each transformation.

The ground truth outputs are excluded from version control because there are 80 of them (as of 10/25/2022), and the output should not clutter git commits.
They should be generated before changes are made to compare outputs against a previous version.

TLDR: Run `make seed_test` if the `tests/regression_data` directory does not exist. Run `make test` to execute the tests.

(3) tests various helper functions.